@@ -9,6 +9,17 @@ require_relative 'context'
 # This has to be done at the top level. It allows us to define constants within the given class while still retaining top-level constant resolution.
 Sus::TOPLEVEL_CLASS_EVAL = ->(__klass__, __path__){__klass__.class_eval(::File.read(__path__), __path__)}
 
+# This is a hack to allow us to get the line number of a syntax error.
+unless SyntaxError.method_defined?(:lineno)
+	class SyntaxError
+		def lineno
+			if message =~ /:(\d+):/
+				$1.to_i
+			end
+		end
+	end
+end
+
 module Sus
 	module File
 		extend Context
@@ -19,11 +30,17 @@ module Sus
 		
 		def self.build(parent, path)
 			base = Class.new(parent)
+			
 			base.extend(File)
 			base.description = path
-			base.identity = Identity.new(path)
+			base.identity = Identity.file(parent.identity, path)
 			
-			TOPLEVEL_CLASS_EVAL.call(base, path)
+			begin
+				TOPLEVEL_CLASS_EVAL.call(base, path)
+			rescue StandardError, LoadError, SyntaxError => error
+				# We add this as a child of the base class so that it is included in the tree under the file rather than completely replacing it, which can be confusing:
+				base.add FileLoadError.build(self, path, error)
+			end
 			
 			return base
 		end
@@ -35,7 +52,16 @@ module Sus
 	
 	class FileLoadError
 		def self.build(parent, path, error)
-			self.new(Identity.new(path), path, error)
+			identity = Identity.file(parent.identity, path)
+			
+			# This is a mess.
+			if error.is_a?(SyntaxError) and error.path == path
+				identity = identity.with_line(error.lineno)
+			else
+				identity = identity.scoped(error.backtrace_locations)
+			end
+			
+			self.new(identity, path, error)
 		end
 		
 		def initialize(identity, path, error)
@@ -45,11 +71,22 @@ module Sus
 		end
 		
 		attr :identity
+		attr :error
 		
 		def leaf?
 			true
 		end
 		
+		EMPTY = Hash.new.freeze
+		
+		def children
+			EMPTY
+		end
+		
+		def description
+			@path
+		end
+		
 		def print(output)
 			output.write("file ", :path, @identity)
 		end
@@ -66,8 +103,6 @@ module Sus
 	module Context
 		def file(path)
 			add File.build(self, path)
-		rescue StandardError, LoadError, SyntaxError => error
-			add FileLoadError.build(self, path, error)
 		end
 	end
 end
